@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkOpenGLRenderer extends vtkRenderer
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -43,6 +43,14 @@ public class vtkOpenGLRenderer extends vtkRenderer
   public boolean HaveApplePrimitiveIdBug()
     { return HaveApplePrimitiveIdBug_8(); }
 
+  private native boolean HaveAppleQueryAllocationBug_9();
+  public boolean HaveAppleQueryAllocationBug()
+    { return HaveAppleQueryAllocationBug_9(); }
+
+  private native boolean IsDualDepthPeelingSupported_10();
+  public boolean IsDualDepthPeelingSupported()
+    { return IsDualDepthPeelingSupported_10(); }
+
   public vtkOpenGLRenderer() { super(); }
 
   public vtkOpenGLRenderer(long id) { super(id); }
