@@ -67,125 +67,149 @@ public class vtkPLYWriter extends vtkWriter
   public void SetColorModeToOff()
     { SetColorModeToOff_14(); }
 
-  private native void SetArrayName_15(String id0);
+  private native void SetEnableAlpha_15(boolean id0);
+  public void SetEnableAlpha(boolean id0)
+    { SetEnableAlpha_15(id0); }
+
+  private native boolean GetEnableAlpha_16();
+  public boolean GetEnableAlpha()
+    { return GetEnableAlpha_16(); }
+
+  private native void EnableAlphaOn_17();
+  public void EnableAlphaOn()
+    { EnableAlphaOn_17(); }
+
+  private native void EnableAlphaOff_18();
+  public void EnableAlphaOff()
+    { EnableAlphaOff_18(); }
+
+  private native void SetArrayName_19(String id0);
   public void SetArrayName(String id0)
-    { SetArrayName_15(id0); }
+    { SetArrayName_19(id0); }
 
-  private native String GetArrayName_16();
+  private native String GetArrayName_20();
   public String GetArrayName()
-    { return GetArrayName_16(); }
+    { return GetArrayName_20(); }
 
-  private native void SetComponent_17(int id0);
+  private native void SetComponent_21(int id0);
   public void SetComponent(int id0)
-    { SetComponent_17(id0); }
+    { SetComponent_21(id0); }
 
-  private native int GetComponentMinValue_18();
+  private native int GetComponentMinValue_22();
   public int GetComponentMinValue()
-    { return GetComponentMinValue_18(); }
+    { return GetComponentMinValue_22(); }
 
-  private native int GetComponentMaxValue_19();
+  private native int GetComponentMaxValue_23();
   public int GetComponentMaxValue()
-    { return GetComponentMaxValue_19(); }
+    { return GetComponentMaxValue_23(); }
 
-  private native int GetComponent_20();
+  private native int GetComponent_24();
   public int GetComponent()
-    { return GetComponent_20(); }
+    { return GetComponent_24(); }
 
-  private native void SetLookupTable_21(vtkScalarsToColors id0);
+  private native void SetLookupTable_25(vtkScalarsToColors id0);
   public void SetLookupTable(vtkScalarsToColors id0)
-    { SetLookupTable_21(id0); }
+    { SetLookupTable_25(id0); }
 
-  private native long GetLookupTable_22();
+  private native long GetLookupTable_26();
   public vtkScalarsToColors GetLookupTable() {
-    long temp = GetLookupTable_22();
+    long temp = GetLookupTable_26();
 
     if (temp == 0) return null;
     return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetColor_23(char id0,char id1,char id2);
+  private native void SetColor_27(char id0,char id1,char id2);
   public void SetColor(char id0,char id1,char id2)
-    { SetColor_23(id0,id1,id2); }
+    { SetColor_27(id0,id1,id2); }
 
-  private native byte[] GetColor_24();
+  private native byte[] GetColor_28();
   public byte[] GetColor()
-    { return GetColor_24(); }
+    { return GetColor_28(); }
 
-  private native long GetInput_25();
+  private native void SetAlpha_29(char id0);
+  public void SetAlpha(char id0)
+    { SetAlpha_29(id0); }
+
+  private native int GetAlpha_30();
+  public int GetAlpha()
+    { return GetAlpha_30(); }
+
+  private native long GetInput_31();
   public vtkPolyData GetInput() {
-    long temp = GetInput_25();
+    long temp = GetInput_31();
 
     if (temp == 0) return null;
     return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetInput_26(int id0);
+  private native long GetInput_32(int id0);
   public vtkPolyData GetInput(int id0) {
-    long temp = GetInput_26(id0);
+    long temp = GetInput_32(id0);
 
     if (temp == 0) return null;
     return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetFileName_27(String id0);
+  private native void SetFileName_33(String id0);
   public void SetFileName(String id0)
-    { SetFileName_27(id0); }
+    { SetFileName_33(id0); }
 
-  private native String GetFileName_28();
+  private native String GetFileName_34();
   public String GetFileName()
-    { return GetFileName_28(); }
+    { return GetFileName_34(); }
 
-  private native void SetFileType_29(int id0);
+  private native void SetFileType_35(int id0);
   public void SetFileType(int id0)
-    { SetFileType_29(id0); }
+    { SetFileType_35(id0); }
 
-  private native int GetFileTypeMinValue_30();
+  private native int GetFileTypeMinValue_36();
   public int GetFileTypeMinValue()
-    { return GetFileTypeMinValue_30(); }
+    { return GetFileTypeMinValue_36(); }
 
-  private native int GetFileTypeMaxValue_31();
+  private native int GetFileTypeMaxValue_37();
   public int GetFileTypeMaxValue()
-    { return GetFileTypeMaxValue_31(); }
+    { return GetFileTypeMaxValue_37(); }
 
-  private native int GetFileType_32();
+  private native int GetFileType_38();
   public int GetFileType()
-    { return GetFileType_32(); }
+    { return GetFileType_38(); }
 
-  private native void SetFileTypeToASCII_33();
+  private native void SetFileTypeToASCII_39();
   public void SetFileTypeToASCII()
-    { SetFileTypeToASCII_33(); }
+    { SetFileTypeToASCII_39(); }
 
-  private native void SetFileTypeToBinary_34();
+  private native void SetFileTypeToBinary_40();
   public void SetFileTypeToBinary()
-    { SetFileTypeToBinary_34(); }
+    { SetFileTypeToBinary_40(); }
 
-  private native void SetTextureCoordinatesName_35(int id0);
+  private native void SetTextureCoordinatesName_41(int id0);
   public void SetTextureCoordinatesName(int id0)
-    { SetTextureCoordinatesName_35(id0); }
+    { SetTextureCoordinatesName_41(id0); }
 
-  private native int GetTextureCoordinatesNameMinValue_36();
+  private native int GetTextureCoordinatesNameMinValue_42();
   public int GetTextureCoordinatesNameMinValue()
-    { return GetTextureCoordinatesNameMinValue_36(); }
+    { return GetTextureCoordinatesNameMinValue_42(); }
 
-  private native int GetTextureCoordinatesNameMaxValue_37();
+  private native int GetTextureCoordinatesNameMaxValue_43();
   public int GetTextureCoordinatesNameMaxValue()
-    { return GetTextureCoordinatesNameMaxValue_37(); }
+    { return GetTextureCoordinatesNameMaxValue_43(); }
 
-  private native int GetTextureCoordinatesName_38();
+  private native int GetTextureCoordinatesName_44();
   public int GetTextureCoordinatesName()
-    { return GetTextureCoordinatesName_38(); }
+    { return GetTextureCoordinatesName_44(); }
 
-  private native void SetTextureCoordinatesNameToUV_39();
+  private native void SetTextureCoordinatesNameToUV_45();
   public void SetTextureCoordinatesNameToUV()
-    { SetTextureCoordinatesNameToUV_39(); }
+    { SetTextureCoordinatesNameToUV_45(); }
 
-  private native void SetTextureCoordinatesNameToTextureUV_40();
+  private native void SetTextureCoordinatesNameToTextureUV_46();
   public void SetTextureCoordinatesNameToTextureUV()
-    { SetTextureCoordinatesNameToTextureUV_40(); }
+    { SetTextureCoordinatesNameToTextureUV_46(); }
 
-  private native void AddComment_41(String id0);
+  private native void AddComment_47(String id0);
   public void AddComment(String id0)
-    { AddComment_41(id0); }
+    { AddComment_47(id0); }
 
   public vtkPLYWriter() { super(); }
 
